
;; This domain file was automatically created by a PANDA-XML-to-PDDL converter.

;; Version 1.0 by Pascal Bercher
;; pascal.bercher@uni-ulm.de, http://www.uni-ulm.de/en/in/ki/bercher

;; The domain described here is the one used in the follwoing paper:
;;
;; @Inproceedings { Bercher14HybridPlanningApplication,
;;   title      = {Plan, Repair, Execute, Explain - How Planning Helps to 
;;                 Assemble your Home Theater},
;;   year       = {2014},
;;   pages      = {386--394},
;;   abstract   = {In various social, work-related, or educational contexts, 
;;                 an increasing demand for intelligent assistance systems can
;;                 be observed. In this paper, we present a domain-independent
;;                 approach that combines a number of planning and interaction
;;                 components to realize advanced user assistance. Based on a 
;;                 components provide hybrid planning formalism, the facilities
;;                 including the generation, execution, and repair as well as the
;;                 presentation and explanation of plans. We demonstrate the 
;;                 feasibility of our approach by means of a system that aims to 
;;                 assist users in the assembly of their home theater. An empirical
;;                 evaluation shows the benefit of such a supportive system, in
;;                 particular for persons with a lack of domain expertise.},
;;   url        = {http://www.aaai.org/ocs/index.php/ICAPS/ICAPS14/paper/view/7901}
;;   publisher  = {AAAI Press},
;;   booktitle  = {Proceedings of the 24th International Conference on Automated 
;;                 Planning and Scheduling (ICAPS 2014)},
;;   author     = {Bercher, Pascal and Biundo, Susanne and Geier, Thomas and Hoernle, 
;;                 Thilo and Nothdurft, Florian and Richter, Felix and Schattenberg, Bernd}
;;                }
;;

;; Note that our planning language does not support conditional effects. 
;; Several actions of the domain rely on that feature, however. We did 
;; compile these conditional effects away in a manual matter. This compilation
;; incorporates the given problem instance. The action 
;; estTwoVideoFromAdapterToESystem is an example.
 
;; All cables, for instance, are devided into different sub sorts of sort Cable. 
;; These subsorts are never used by the actions, but they are used to create the 
;; initial state (manually), since some properties rely on the sub sort. For 
;; instance, to build (all) the correct groundings of PortIsCompatible(?port1,?port2), 
;; the respective cabe sub sorts were investigated. E.g., all SPDIF coaxial ports 
;; are compatible with all CINCH video ports.

;; It follows are short explanation how the domain model works w.r.t. the ports; 
;; note that the constants are given in the problem instance. A visualization of 
;; that problem is given by a PDF.

;; For every port of some sort (like the HDMI ports, sort: Port_HDMI), there
;; are several port constants in the problem instance (p_HDMI_i, i in {1,...,n}). 
;; For the available devices, not all ports have been modeled, but only sufficiently
;; many w.r.t. the available devices. For example, the A/V receiver (e_Amplifier) 
;; has only one HMDI output port (p_HDMI_3) and six HDMI input ports. For the input
;; ports, only two have been modeled (using p_HDMI_1 and p_HDMI_2).

;; Note that there are *not* individual port constants for the different devices 
;; and cables. Instead, the port constants are used by several devices/cables. 
;; For instance, the constants p_HDMI_1 and p_HDMI_2 are used by all HDMI cables
;; (one constant for one end) and also by the TV, the A/V receiver and the Blu-ray
;; player. As a detailed example, consider one of the HDMI input ports of 
;; the A/V receiver. It is specified (in the problem) via:
;; PortIsFemale(e_Amplifier,p_HDMI_1)
;; PortIsSignalIn(e_Amplifier,p_HDMI_1)
;; PortIsAudio(e_Amplifier,p_HDMI_1)
;; PortIsVideo(e_Amplifier,p_HDMI_1)

(define (domain AssemblyTask_domain)

  (:types
    Cable_DVI Cable_HDMI_DVI - Cable_pureVideo
    Cable_Headphone_CinchStereo Cable_SPDIFoptical Cable_CinchStereo - Cable_pureAudio
    Cable_CinchVideo - Cable_Audio_exclusiveOr_Video
    BlurayPlayer Receiver - SignalSource
    Cable_HDMI Cable_Scart_CinchVideo_CinchStereo - Cable_Audio_and_Video
    Port_HDMI Port_VGA Port_Headphone Port_SPDIFcoaxial Port_SPDIFoptical Port_CinchVideo Port_CinchStereo Port_DVI Port_Scart - Port
    SignalSource TV Amplifier - EntertainmentSystem
    EntertainmentSystem Adapter - Device
    Cable_pureVideo Cable_Audio_and_Video Cable_Audio_exclusiveOr_Video - Cable_Video
    Cable_pureAudio Cable_Audio_and_Video Cable_Audio_exclusiveOr_Video - Cable_Audio
    Cable_Audio Cable_Video - Cable
    Cable Device - SignalTransporter
  )

  (:predicates

    ;; Specifies that the given ports are matching. Note that we do not 
    ;; distinct between input and output ports here: this is done by the
    ;; actions using the PortIsSignalIn() and PortIsSignalOut() relations.
    (PortsAreCompatible ?Port_1 - Port ?Port_2 - Port)

    (hasVideoSignal ?SignalTransporter - SignalTransporter ?SignalSource - SignalSource)
    (PortIsSignalIn ?SignalTransporter - SignalTransporter ?Port - Port)
    (PortIsFemale ?SignalTransporter - SignalTransporter ?Port - Port)
    (PortIsSignalOut ?SignalTransporter - SignalTransporter ?Port - Port)
    (PortIsVideo ?SignalTransporter - SignalTransporter ?Port - Port)
    (PortIsAudio ?SignalTransporter - SignalTransporter ?Port - Port)
    (PortIsMale ?SignalTransporter - SignalTransporter ?Port - Port)
    (SignalTransporterIsBroken ?SignalTransporter - SignalTransporter)
    (DeviceToCableConnected ?Device - Device ?Cable - Cable)
    (PortIsUsed ?SignalTransporter - SignalTransporter ?Port - Port)
    (hasAudioSignal ?SignalTransporter - SignalTransporter ?SignalSource - SignalSource)
  )

  (:action estOneVideoFromCableToDevice
   :parameters (?v1 - Cable_Video
                ?v2 - Port
                ?v3 - Device
                ?v4 - Port
                ?v5 - SignalSource)
   :precondition
     (and
       (PortIsVideo ?v3 ?v4)
       (PortIsVideo ?v1 ?v2)
       (PortIsFemale ?v3 ?v4)
       (PortIsMale ?v1 ?v2)
       (PortsAreCompatible ?v2 ?v4)
       (not (SignalTransporterIsBroken ?v3))
       (not (SignalTransporterIsBroken ?v1))
       (hasVideoSignal ?v1 ?v5)
       (not (PortIsUsed ?v3 ?v4))
       (PortIsSignalIn ?v3 ?v4)
       (not (PortIsUsed ?v1 ?v2))
       (PortIsSignalOut ?v1 ?v2)
     )
   :effect
     (and
       (DeviceToCableConnected ?v3 ?v1)
       (PortIsUsed ?v3 ?v4)
       (PortIsUsed ?v1 ?v2)
       (hasVideoSignal ?v3 ?v5)
     )
  )

  (:action estTwoAudioFromDeviceToCable
   :parameters (?v1 - Device
                ?v2 - Port
                ?v3 - Cable_Audio
                ?v4 - Port
                ?v5 - Receiver
                ?v6 - BlurayPlayer)
   :precondition
     (and
       (PortIsAudio ?v1 ?v2)
       (PortIsAudio ?v3 ?v4)
       (not (DeviceToCableConnected ?v1 ?v3))
       (PortIsFemale ?v1 ?v2)
       (PortIsMale ?v3 ?v4)
       (not (PortIsUsed ?v3 ?v4))
       (PortsAreCompatible ?v4 ?v2)
       (not (SignalTransporterIsBroken ?v1))
       (not (SignalTransporterIsBroken ?v3))
       (hasAudioSignal ?v1 ?v6)
       (hasAudioSignal ?v1 ?v5)
       (PortIsSignalIn ?v3 ?v4)
       (not (PortIsUsed ?v1 ?v2))
       (PortIsSignalOut ?v1 ?v2)
     )
   :effect
     (and
       (DeviceToCableConnected ?v1 ?v3)
       (PortIsUsed ?v3 ?v4)
       (PortIsUsed ?v1 ?v2)
       (hasAudioSignal ?v3 ?v6)
       (hasAudioSignal ?v3 ?v5)
     )
  )

  (:action estVideoAndAudioFromDeviceToCable_A1V1_or_A2V2
   :parameters (?v1 - Device
                ?v2 - Port
                ?v3 - Cable_Audio_and_Video
                ?v4 - Port
                ?v5 - SignalSource)
   :precondition
     (and
       (PortIsAudio ?v1 ?v2)
       (PortIsAudio ?v3 ?v4)
       (PortIsVideo ?v1 ?v2)
       (PortIsVideo ?v3 ?v4)
       (not (DeviceToCableConnected ?v1 ?v3))
       (PortsAreCompatible ?v2 ?v4)
       (PortIsFemale ?v1 ?v2)
       (PortIsMale ?v3 ?v4)
       (not (SignalTransporterIsBroken ?v3))
       (not (SignalTransporterIsBroken ?v1))
       (hasAudioSignal ?v1 ?v5)
       (hasVideoSignal ?v1 ?v5)
       (not (PortIsUsed ?v3 ?v4))
       (PortIsSignalIn ?v3 ?v4)
       (not (PortIsUsed ?v1 ?v2))
       (PortIsSignalOut ?v1 ?v2)
     )
   :effect
     (and
       (DeviceToCableConnected ?v1 ?v3)
       (PortIsUsed ?v3 ?v4)
       (PortIsUsed ?v1 ?v2)
       (hasAudioSignal ?v3 ?v5)
       (hasVideoSignal ?v3 ?v5)
     )
  )

  (:action estOneVideoFromAdapterToESystem
   :parameters (?v1 - Adapter
                ?v2 - Port
                ?v3 - EntertainmentSystem
                ?v4 - Port
                ?v5 - SignalSource)
   :precondition
     (and
       (PortIsVideo ?v3 ?v4)
       (PortIsVideo ?v1 ?v2)
       (PortsAreCompatible ?v2 ?v4)
       (PortIsFemale ?v3 ?v4)
       (PortIsMale ?v1 ?v2)
       (hasVideoSignal ?v1 ?v5)
       (not (PortIsUsed ?v3 ?v4))
       (PortIsSignalIn ?v3 ?v4)
       (not (PortIsUsed ?v1 ?v2))
       (PortIsSignalOut ?v1 ?v2)
     )
   :effect
     (and
       (PortIsUsed ?v3 ?v4)
       (PortIsUsed ?v1 ?v2)
       (hasVideoSignal ?v3 ?v5)
     )
  )

  (:action estTwoVideoFromCableToDevice
   :parameters (?v1 - Cable_Video
                ?v2 - Port
                ?v3 - Device
                ?v4 - Port
                ?v5 - Receiver
                ?v6 - BlurayPlayer)
   :precondition
     (and
       (PortIsVideo ?v3 ?v4)
       (PortIsVideo ?v1 ?v2)
       (not (DeviceToCableConnected ?v3 ?v1))
       (PortIsFemale ?v3 ?v4)
       (PortIsMale ?v1 ?v2)
       (PortsAreCompatible ?v2 ?v4)
       (not (SignalTransporterIsBroken ?v3))
       (not (SignalTransporterIsBroken ?v1))
       (hasVideoSignal ?v1 ?v6)
       (hasVideoSignal ?v1 ?v5)
       (not (PortIsUsed ?v3 ?v4))
       (PortIsSignalIn ?v3 ?v4)
       (not (PortIsUsed ?v1 ?v2))
       (PortIsSignalOut ?v1 ?v2)
     )
   :effect
     (and
       (DeviceToCableConnected ?v3 ?v1)
       (PortIsUsed ?v3 ?v4)
       (PortIsUsed ?v1 ?v2)
       (hasVideoSignal ?v3 ?v6)
       (hasVideoSignal ?v3 ?v5)
     )
  )

  (:action estTwoVideoFromESystemToAdapter
   :parameters (?v1 - EntertainmentSystem
                ?v2 - Port
                ?v3 - Adapter
                ?v4 - Port
                ?v5 - Receiver
                ?v6 - BlurayPlayer)
   :precondition
     (and
       (PortIsVideo ?v1 ?v2)
       (PortIsVideo ?v3 ?v4)
       (not (SignalTransporterIsBroken ?v3))
       (not (SignalTransporterIsBroken ?v1))
       (PortsAreCompatible ?v2 ?v4)
       (PortIsMale ?v3 ?v4)
       (PortIsFemale ?v1 ?v2)
       (hasVideoSignal ?v1 ?v6)
       (hasVideoSignal ?v1 ?v5)
       (not (PortIsUsed ?v3 ?v4))
       (PortIsSignalIn ?v3 ?v4)
       (not (PortIsUsed ?v1 ?v2))
       (PortIsSignalOut ?v1 ?v2)
     )
   :effect
     (and
       (PortIsUsed ?v3 ?v4)
       (PortIsUsed ?v1 ?v2)
       (hasVideoSignal ?v3 ?v6)
       (hasVideoSignal ?v3 ?v5)
     )
  )


  ;; Given the adapter has two video signals, this action plugs it into 
  ;; an entertainment system (like a DVD player), s.t. this system also
  ;; has both video signals.
  ;; Note that this action uses problem instance-dependent information: 
  ;; the last two parameters are *all* the signal sources in the problem instance.

  (:action estTwoVideoFromAdapterToESystem
   :parameters (?v1 - Adapter
                ?v2 - Port
                ?v3 - EntertainmentSystem
                ?v4 - Port
                ?v5 - Receiver
                ?v6 - BlurayPlayer)
   :precondition
     (and
       (PortIsVideo ?v3 ?v4)
       (PortIsVideo ?v1 ?v2)
       (PortsAreCompatible ?v2 ?v4)
       (PortIsFemale ?v3 ?v4)
       (PortIsMale ?v1 ?v2)
       (hasVideoSignal ?v1 ?v6)
       (hasVideoSignal ?v1 ?v5)
       (not (PortIsUsed ?v3 ?v4))
       (PortIsSignalIn ?v3 ?v4)
       (not (PortIsUsed ?v1 ?v2))
       (PortIsSignalOut ?v1 ?v2)
     )
   :effect
     (and
       (PortIsUsed ?v3 ?v4)
       (PortIsUsed ?v1 ?v2)
       (hasVideoSignal ?v3 ?v6)
       (hasVideoSignal ?v3 ?v5)
     )
  )

  (:action estVideoAndAudioFromCableToDevice_A1A2V1V2
   :parameters (?v1 - Cable_Audio_and_Video
                ?v2 - Port
                ?v3 - Device
                ?v4 - Port
                ?v5 - Receiver
                ?v6 - BlurayPlayer)
   :precondition
     (and
       (PortIsVideo ?v1 ?v2)
       (PortIsVideo ?v3 ?v4)
       (PortIsAudio ?v3 ?v4)
       (PortIsAudio ?v1 ?v2)
       (not (DeviceToCableConnected ?v3 ?v1))
       (PortIsFemale ?v3 ?v4)
       (PortIsMale ?v1 ?v2)
       (PortsAreCompatible ?v2 ?v4)
       (not (SignalTransporterIsBroken ?v3))
       (not (SignalTransporterIsBroken ?v1))
       (hasVideoSignal ?v1 ?v6)
       (hasVideoSignal ?v1 ?v5)
       (hasAudioSignal ?v1 ?v6)
       (hasAudioSignal ?v1 ?v5)
       (not (PortIsUsed ?v3 ?v4))
       (PortIsSignalIn ?v3 ?v4)
       (not (PortIsUsed ?v1 ?v2))
       (PortIsSignalOut ?v1 ?v2)
     )
   :effect
     (and
       (DeviceToCableConnected ?v3 ?v1)
       (PortIsUsed ?v3 ?v4)
       (PortIsUsed ?v1 ?v2)
       (hasVideoSignal ?v3 ?v6)
       (hasVideoSignal ?v3 ?v5)
       (hasAudioSignal ?v3 ?v6)
       (hasAudioSignal ?v3 ?v5)
     )
  )

  (:action estOneVideoFromDeviceToCable
   :parameters (?v1 - Device
                ?v2 - Port
                ?v3 - Cable_Video
                ?v4 - Port
                ?v5 - SignalSource)
   :precondition
     (and
       (PortIsVideo ?v1 ?v2)
       (PortIsVideo ?v3 ?v4)
       (PortIsFemale ?v1 ?v2)
       (PortIsMale ?v3 ?v4)
       (PortsAreCompatible ?v4 ?v2)
       (not (SignalTransporterIsBroken ?v3))
       (not (SignalTransporterIsBroken ?v1))
       (hasVideoSignal ?v1 ?v5)
       (not (PortIsUsed ?v3 ?v4))
       (PortIsSignalIn ?v3 ?v4)
       (not (PortIsUsed ?v1 ?v2))
       (PortIsSignalOut ?v1 ?v2)
     )
   :effect
     (and
       (PortIsUsed ?v3 ?v4)
       (PortIsUsed ?v1 ?v2)
       (hasVideoSignal ?v3 ?v5)
     )
  )

  (:action estVideoAndAudioFromDeviceToCable_A1A2V1V2
   :parameters (?v1 - Device
                ?v2 - Port
                ?v3 - Cable_Audio_and_Video
                ?v4 - Port
                ?v5 - Receiver
                ?v6 - BlurayPlayer)
   :precondition
     (and
       (PortIsVideo ?v1 ?v2)
       (PortIsVideo ?v3 ?v4)
       (PortIsAudio ?v1 ?v2)
       (PortIsAudio ?v3 ?v4)
       (not (DeviceToCableConnected ?v1 ?v3))
       (PortsAreCompatible ?v2 ?v4)
       (PortIsFemale ?v1 ?v2)
       (PortIsMale ?v3 ?v4)
       (not (SignalTransporterIsBroken ?v3))
       (not (SignalTransporterIsBroken ?v1))
       (hasAudioSignal ?v1 ?v6)
       (hasAudioSignal ?v1 ?v5)
       (hasVideoSignal ?v1 ?v5)
       (hasVideoSignal ?v1 ?v6)
       (not (PortIsUsed ?v3 ?v4))
       (PortIsSignalIn ?v3 ?v4)
       (not (PortIsUsed ?v1 ?v2))
       (PortIsSignalOut ?v1 ?v2)
     )
   :effect
     (and
       (DeviceToCableConnected ?v1 ?v3)
       (PortIsUsed ?v3 ?v4)
       (PortIsUsed ?v1 ?v2)
       (hasVideoSignal ?v3 ?v5)
       (hasVideoSignal ?v3 ?v6)
       (hasAudioSignal ?v3 ?v5)
       (hasAudioSignal ?v3 ?v6)
     )
  )

  (:action estTwoAudioFromCableToDevice
   :parameters (?v1 - Cable_Audio
                ?v2 - Port
                ?v3 - Device
                ?v4 - Port
                ?v5 - Receiver
                ?v6 - BlurayPlayer)
   :precondition
     (and
       (PortIsAudio ?v3 ?v4)
       (PortIsAudio ?v1 ?v2)
       (not (DeviceToCableConnected ?v3 ?v1))
       (PortIsFemale ?v3 ?v4)
       (PortIsMale ?v1 ?v2)
       (PortsAreCompatible ?v4 ?v2)
       (not (SignalTransporterIsBroken ?v3))
       (not (SignalTransporterIsBroken ?v1))
       (hasAudioSignal ?v1 ?v6)
       (hasAudioSignal ?v1 ?v5)
       (not (PortIsUsed ?v3 ?v4))
       (PortIsSignalIn ?v3 ?v4)
       (not (PortIsUsed ?v1 ?v2))
       (PortIsSignalOut ?v1 ?v2)
     )
   :effect
     (and
       (DeviceToCableConnected ?v3 ?v1)
       (PortIsUsed ?v3 ?v4)
       (PortIsUsed ?v1 ?v2)
       (hasAudioSignal ?v3 ?v6)
       (hasAudioSignal ?v3 ?v5)
     )
  )

  (:action estVideoAndAudioFromCableToDevice_A1V1_or_A2V2
   :parameters (?v1 - Cable_Audio_and_Video
                ?v2 - Port
                ?v3 - Device
                ?v4 - Port
                ?v5 - SignalSource)
   :precondition
     (and
       (PortIsVideo ?v3 ?v4)
       (PortIsVideo ?v1 ?v2)
       (PortIsAudio ?v3 ?v4)
       (PortIsAudio ?v1 ?v2)
       (not (DeviceToCableConnected ?v3 ?v1))
       (PortIsFemale ?v3 ?v4)
       (PortIsMale ?v1 ?v2)
       (PortsAreCompatible ?v2 ?v4)
       (not (SignalTransporterIsBroken ?v3))
       (not (SignalTransporterIsBroken ?v1))
       (hasVideoSignal ?v1 ?v5)
       (hasAudioSignal ?v1 ?v5)
       (not (PortIsUsed ?v3 ?v4))
       (PortIsSignalIn ?v3 ?v4)
       (not (PortIsUsed ?v1 ?v2))
       (PortIsSignalOut ?v1 ?v2)
     )
   :effect
     (and
       (DeviceToCableConnected ?v3 ?v1)
       (PortIsUsed ?v3 ?v4)
       (PortIsUsed ?v1 ?v2)
       (hasVideoSignal ?v3 ?v5)
       (hasAudioSignal ?v3 ?v5)
     )
  )

  (:action estOneVideoFromESystemToAdapter
   :parameters (?v1 - EntertainmentSystem
                ?v2 - Port
                ?v3 - Adapter
                ?v4 - Port
                ?v5 - SignalSource)
   :precondition
     (and
       (PortIsVideo ?v1 ?v2)
       (PortIsVideo ?v3 ?v4)
       (not (SignalTransporterIsBroken ?v3))
       (not (SignalTransporterIsBroken ?v1))
       (PortsAreCompatible ?v2 ?v4)
       (PortIsMale ?v3 ?v4)
       (PortIsFemale ?v1 ?v2)
       (hasVideoSignal ?v1 ?v5)
       (not (PortIsUsed ?v3 ?v4))
       (PortIsSignalIn ?v3 ?v4)
       (not (PortIsUsed ?v1 ?v2))
       (PortIsSignalOut ?v1 ?v2)
     )
   :effect
     (and
       (PortIsUsed ?v3 ?v4)
       (PortIsUsed ?v1 ?v2)
       (hasVideoSignal ?v3 ?v5)
     )
  )

  (:action estOneAudioFromDeviceToCable
   :parameters (?v1 - Device
                ?v2 - Port
                ?v3 - Cable_Audio
                ?v4 - Port
                ?v5 - SignalSource)
   :precondition
     (and
       (PortIsAudio ?v1 ?v2)
       (PortIsAudio ?v3 ?v4)
       (not (DeviceToCableConnected ?v1 ?v3))
       (PortIsFemale ?v1 ?v2)
       (PortIsMale ?v3 ?v4)
       (not (PortIsUsed ?v3 ?v4))
       (PortsAreCompatible ?v4 ?v2)
       (not (SignalTransporterIsBroken ?v1))
       (not (SignalTransporterIsBroken ?v3))
       (hasAudioSignal ?v1 ?v5)
       (PortIsSignalIn ?v3 ?v4)
       (not (PortIsUsed ?v1 ?v2))
       (PortIsSignalOut ?v1 ?v2)
     )
   :effect
     (and
       (DeviceToCableConnected ?v1 ?v3)
       (PortIsUsed ?v3 ?v4)
       (PortIsUsed ?v1 ?v2)
       (hasAudioSignal ?v3 ?v5)
     )
  )

  (:action estOneAudioFromCableToDevice
   :parameters (?v1 - Cable_Audio
                ?v2 - Port
                ?v3 - Device
                ?v4 - Port
                ?v5 - SignalSource)
   :precondition
     (and
       (PortIsAudio ?v3 ?v4)
       (PortIsAudio ?v1 ?v2)
       (not (DeviceToCableConnected ?v3 ?v1))
       (PortIsFemale ?v3 ?v4)
       (PortIsMale ?v1 ?v2)
       (PortsAreCompatible ?v4 ?v2)
       (not (SignalTransporterIsBroken ?v3))
       (not (SignalTransporterIsBroken ?v1))
       (hasAudioSignal ?v1 ?v5)
       (not (PortIsUsed ?v3 ?v4))
       (PortIsSignalIn ?v3 ?v4)
       (not (PortIsUsed ?v1 ?v2))
       (PortIsSignalOut ?v1 ?v2)
     )
   :effect
     (and
       (DeviceToCableConnected ?v3 ?v1)
       (PortIsUsed ?v3 ?v4)
       (PortIsUsed ?v1 ?v2)
       (hasAudioSignal ?v3 ?v5)
     )
  )

  (:action estTwoVideoFromDeviceToCable
   :parameters (?v1 - Device
                ?v2 - Port
                ?v3 - Cable_Video
                ?v4 - Port
                ?v5 - BlurayPlayer
                ?v6 - Receiver)
   :precondition
     (and
       (PortIsVideo ?v1 ?v2)
       (PortIsVideo ?v3 ?v4)
       (PortIsFemale ?v1 ?v2)
       (PortIsMale ?v3 ?v4)
       (PortsAreCompatible ?v4 ?v2)
       (not (SignalTransporterIsBroken ?v3))
       (not (SignalTransporterIsBroken ?v1))
       (hasVideoSignal ?v1 ?v6)
       (hasVideoSignal ?v1 ?v5)
       (not (PortIsUsed ?v3 ?v4))
       (PortIsSignalIn ?v3 ?v4)
       (not (PortIsUsed ?v1 ?v2))
       (PortIsSignalOut ?v1 ?v2)
     )
   :effect
     (and
       (PortIsUsed ?v3 ?v4)
       (PortIsUsed ?v1 ?v2)
       (hasVideoSignal ?v3 ?v6)
       (hasVideoSignal ?v3 ?v5)
     )
  )

)
